[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

[SCM] Debian package checker branch, master, updated. 2.5.2-24-g53764d2



The following commit has been merged in the master branch:
commit 53764d27b408c81eea7e1fd198e2ae263968faf3
Author: Niels Thykier <niels@thykier.net>
Date:   Tue Aug 16 18:16:57 2011 +0200

    Updated the L::C::Source doc to reflect the current state

diff --git a/lib/Lintian/Collect/Source.pm b/lib/Lintian/Collect/Source.pm
index 44e7512..d4b6acd 100644
--- a/lib/Lintian/Collect/Source.pm
+++ b/lib/Lintian/Collect/Source.pm
@@ -110,8 +110,8 @@ sub binaries {
     return $self->{binaries};
 }
 
 # Returns the value of a control field for a binary package or the empty
 # string if that control field isn't present.  This does not implement
 # inheritance from the settings in the source stanza.
 # sub binary_field Needs-Info debfiles
 sub binary_field {
@@ -324,20 +324,18 @@ documented in the Lintian::Collect module are also available.
 
 Returns a hash reference with the binary package names as keys and the
 Package-Type as value (which should be either C<deb> or C<udeb>
-currently).  The source-control-file collection script must have been run
-to parse the F<debian/control> file and put the fields in the F<control>
-directory in the lab.
+currently).  The debfiles collection script must have been run
+to make the F<debfiles/control> file available.
 
 =item binary_field(PACKAGE, FIELD)
 
 Returns the content of the field FIELD for the binary package PACKAGE in
-the F<debian/control> file, or an empty string if that field isn't set.
+the F<debian/control> file, or an undef if the field is not present.
 Inheritance of field values from the source section of the control file is
 not implemented.  Only the literal value of the field is returned.
 
-The source-control-file collection script must have been run to parse the
-F<debian/control> file and put the fields in the F<control> directory in
-the lab.
+The debfiles collection script must have been run to make the
+F<debfiles/control> file available.
 
 =item binary_relation(PACKAGE, FIELD)
 
@@ -110,8 +110,8 @@ sub binaries {
 }
 
-# Returns the value of a control field for a binary package or the empty
-# string if that control field isn't present.  This does not implement
+# Returns the value of a control field for a binary package or undef
+# if that control field isn't present.  This does not implement
 # inheritance from the settings in the source stanza.
 # sub binary_field Needs-Info debfiles

-- 
Debian package checker


Reply to: